@@ -2,10 +2,11 @@
     基础的 item
 """
 import json
+from loguru import logger
 
 
 class BaseItem:
-    table = None  # 表名
+    __table_name__ = None  # 表名
 
     def to_dict(self) -> dict:
         """
@@ -31,5 +32,12 @@ class BaseItem:
 
         return json.dumps(self.to_dict(), **kwargs)
 
+    def __setattr__(self, key, value):
+        if not isinstance(key, str):
+            logger.warning("item key 必须是一个字符串")
+            key = str(key)
+
+        self.__dict__[key] = value
+
     def __str__(self):
-        return f"<{self.__class__.__name__} table:{self.__class__.table} item:{self.to_dict()}>"
+        return f"<{self.__class__.__name__} table:{self.__class__.__table_name__} item:{self.to_dict()}>"
